pub struct InteractionEntityDataView<'a> {
guard: MutexGuard<'a, InteractionEntityData>,
dimensions_changed: bool,
}Expand description
Provides an exclusive view of the synchronized entity data of an interaction entity.
This includes its width, its height, and the response boolean.
Fields
guard: MutexGuard<'a, InteractionEntityData>dimensions_changed: boolImplementations
Sourceimpl InteractionEntityDataView<'_>
impl InteractionEntityDataView<'_>
Sourcepub fn set_width(&mut self, width: f32)
pub fn set_width(&mut self, width: f32)
Sets the width of the bounding box of the interaction entity to the provided value.
Sourcepub fn set_height(&mut self, height: f32)
pub fn set_height(&mut self, height: f32)
Sets the height of the bounding box of the interaction entity to the provided value.
Sourcepub fn response(&self) -> bool
pub fn response(&self) -> bool
Gets whether interacting with the interaction entity will trigger a response
from the player. If true, this means that
- for left clicks, a punching sound will play, and
- for right clicks, the player’s hand will swing.
Sourcepub fn set_response(&mut self, response: bool)
pub fn set_response(&mut self, response: bool)
Sets whether interacting with the interaction entity will trigger a response
from the player. If set to true, this means that
- for left clicks, a punching sound will play, and
- for right clicks, the player’s hand will swing.